@@ -29,9 +29,12 @@
  * org.freedesktop.Telepathy.Channel.Type.Call that has HardwareStreaming=FALSE
  */
 
+#include "config.h"
+
 #include <stdlib.h>
 
 #include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #include <farstream/fs-conference.h>
 
@@ -137,11 +140,8 @@ tf_channel_get_property (GObject    *object,
       g_value_set_object (value, self->priv->channel_proxy);
       break;
     case PROP_OBJECT_PATH:
-        {
-          TpProxy *as_proxy = (TpProxy *) self->priv->channel_proxy;
-
-          g_value_set_string (value, as_proxy->object_path);
-        }
+      g_value_set_string (value,
+          tp_proxy_get_object_path (self->priv->channel_proxy));
       break;
     case PROP_FS_CONFERENCES:
       if (self->priv->call_channel)
@@ -358,7 +358,7 @@ channel_prepared (GObject *obj,
     }
   else
     {
-      g_simple_async_result_set_error (res, TP_ERRORS, TP_ERROR_NOT_IMPLEMENTED,
+      g_simple_async_result_set_error (res, TP_ERROR, TP_ERROR_NOT_IMPLEMENTED,
           "Channel does not implement "
           TP_IFACE_CHANNEL_INTERFACE_MEDIA_SIGNALLING " or "
           TP_IFACE_CHANNEL_TYPE_CALL);
@@ -504,7 +504,7 @@ tf_channel_class_init (TfChannelClass *klass)
           G_TYPE_NONE, 0);
 
   /**
-   * TfChannel::fs-conference-added
+   * TfChannel::fs-conference-added:
    * @tfchannel: the #TfChannel
    * @conf: a #FsConference
    *
@@ -519,7 +519,7 @@ tf_channel_class_init (TfChannelClass *klass)
       G_TYPE_NONE, 1, FS_TYPE_CONFERENCE);
 
   /**
-   * TfChannel::fs-conference-removed
+   * TfChannel::fs-conference-removed:
    * @tfchannel: the #TfChannel
    * @conf: a #FsConference
    *
@@ -535,7 +535,7 @@ tf_channel_class_init (TfChannelClass *klass)
 
 
   /**
-   * TfChannel::content-added
+   * TfChannel::content-added:
    * @tfchannel: the #TfChannel
    * @content: a #TfContent
    *
@@ -553,7 +553,7 @@ tf_channel_class_init (TfChannelClass *klass)
       G_TYPE_NONE, 1, TF_TYPE_CONTENT);
 
   /**
-   * TfChannel::content-removed
+   * TfChannel::content-removed:
    * @tfchannel: the #TfChannel
    * @content: a #TfContent
    *
